aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rwxr-xr-xscripts/.local/bin/ttl.sh4
1 files changed, 2 insertions, 2 deletions
diff --git a/scripts/.local/bin/ttl.sh b/scripts/.local/bin/ttl.sh
index 20c13e5..9cdabf0 100755
--- a/scripts/.local/bin/ttl.sh
+++ b/scripts/.local/bin/ttl.sh
@@ -1,11 +1,11 @@
#!/bin/sh
# Fix default TTL and disable ipv6 making changes permanent
# TODO: replace wlo1 with automatically detected device name
sudo sysctl \
net.ipv4.ip_default_ttl=65 \
net.ipv6.conf.all.disable_ipv6=1\
net.ipv6.conf.default.disable_ipv6=1 \
- net.ipv6.conf.wlo1.disable_ipv6=1 \
+ net.ipv6.conf.wlan0.disable_ipv6=1 \
| sudo tee /etc/sysctl.d/fix-ttl.conf -a
@@ -1,11 +1,11 @@
#!/bin/sh
# Fix default TTL and disable ipv6 making changes permanent
-# TODO: replace wlo1 with automatically detected device name
+# TODO: replace wlan0 with automatically detected device name
sudo sysctl \
net.ipv4.ip_default_ttl=65 \